@@ -7,6 +7,8 @@
 #' @inheritParams bigstatsr-package
 #' @param A.col A matrix with `length(ind.col)` rows.
 #'
+#' @inheritSection bigstatsr-package Matrix parallelization
+#'
 #' @return \eqn{X \cdot A}.
 #' @export
 #'
@@ -38,10 +40,14 @@ big_prodMat <- function(X, A.col,
                         ind.row = rows_along(X),
                         ind.col = cols_along(X),
                         ncores = 1,
-                        block.size = block_size(nrow(X), ncores),
+                        block.size = block_size(nrow(X)),
                         center = NULL,
                         scale = NULL) {
 
+  if (!missing(ncores))
+    warning2("Parameter 'ncores' is deprecated; please use '%s' instead.",
+             "bigparallelr::set_blas_ncores()")
+
   check_args()
   assert_lengths(ind.col, rows_along(A.col))
   # assert_class(A.col, 'matrix')  # not only (e.g. sparse matrices)
@@ -58,11 +64,7 @@ big_prodMat <- function(X, A.col,
     center2 <- crossprod(as_vec(center), A.col)
   }
 
-  res <- big_apply(X, a.FUN = function(X, ind, M, ind.row, ind.col) {
-    X[ind.row, ind.col[ind], drop = FALSE] %*% M[ind, , drop = FALSE]
-  }, a.combine = plus, ind = seq_along(ind.col),
-  ncores = ncores, block.size = block.size,
-  M = A.col, ind.row = ind.row, ind.col = ind.col)
+  res <- prod_FBM_block_mat(X, A.col, ind.row, ind.col, block.size)
 
   `if`(is.null(center), res, centering(res, center2))
 }
@@ -91,6 +93,8 @@ setMethod("%*%", signature(x = "matrix", y = "FBM"),
 #' @inheritParams bigstatsr-package
 #' @param A.row A matrix with `length(ind.row)` rows.
 #'
+#' @inheritSection bigstatsr-package Matrix parallelization
+#'
 #' @return \eqn{X^T \cdot A}.
 #' @export
 #'
@@ -122,10 +126,14 @@ big_cprodMat <- function(X, A.row,
                          ind.row = rows_along(X),
                          ind.col = cols_along(X),
                          ncores = 1,
-                         block.size = block_size(nrow(X), ncores),
+                         block.size = block_size(nrow(X)),
                          center = NULL,
                          scale = NULL) {
 
+  if (!missing(ncores))
+    warning2("Parameter 'ncores' is deprecated; please use '%s' instead.",
+             "bigparallelr::set_blas_ncores()")
+
   check_args()
   assert_lengths(ind.row, rows_along(A.row))
   # assert_class(A.row, 'matrix')  # not only (e.g. sparse matrices)
@@ -142,11 +150,7 @@ big_cprodMat <- function(X, A.row,
     center <- as_vec(center)
   }
 
-  res <- big_apply(X, a.FUN = function(X, ind, M, ind.row) {
-    crossprod(X[ind.row, ind, drop = FALSE], M)
-  }, a.combine = rbind, ind = ind.col,
-  ncores = ncores, block.size = block.size,
-  M = A.row, ind.row = ind.row)
+  res <- cprod_FBM_block_mat(X, A.row, ind.row, ind.col, block.size)
 
   if (!is.null(center)) res <- res - tcrossprod(center, colSums(A.row))
   if (!is.null(scale))  res <- res / scale
