@@ -30,7 +30,7 @@ if (not_cran) {
 
     for (t in TEST.TYPES) {
 
-      X <- `if`(t == "raw", asFBMcode(x), big_copy(x, type = t))
+      X <- `if`(t == "raw", asFBMcode(x, TRUE), big_copy(x, type = t))
 
       for (covar in sample(lcovar, 1)) {
 
@@ -93,7 +93,7 @@ if (not_cran) {
 
     for (t in TEST.TYPES) {
 
-      X <- `if`(t == "raw", asFBMcode(x), big_copy(x, type = t))
+      X <- `if`(t == "raw", asFBMcode(x, TRUE), big_copy(x, type = t))
 
       ind.col <- cols_along(X)[-set]
       ind.novar <- sample(ind.col, 10); X[, ind.novar] <- 100
@@ -172,7 +172,7 @@ if (not_cran) {
 
     for (t in TEST.TYPES) {
 
-      X <- `if`(t == "raw", asFBMcode(x), big_copy(x, type = t))
+      X <- `if`(t == "raw", asFBMcode(x, TRUE), big_copy(x, type = t))
 
       for (covar in sample(lcovar, 1)) {
 
@@ -210,7 +210,7 @@ if (not_cran) {
 
     for (t in TEST.TYPES) {
 
-      X <- `if`(t == "raw", asFBMcode(x), big_copy(x, type = t))
+      X <- `if`(t == "raw", asFBMcode(x, TRUE), big_copy(x, type = t))
 
       for (covar in sample(lcovar, 1)) {
 
@@ -296,3 +296,21 @@ test_that("Warns if not all converged", {
 })
 
 ################################################################################
+
+test_that("code is used for FBM.code256", {
+
+  # simulating some data
+  N <- 230
+  M <- 730
+  X <- FBM.code256(N, M, init = rnorm(N * M, sd = 5), code = rnorm(256))
+  y01 <- as.numeric((rowSums(X[, 1:10]) + rnorm(N)) > 0)
+  covar <- matrix(rnorm(N * 3), N)
+
+  test <- big_spLogReg(X, y01, K = 5)
+
+  X2 <- X$copy(code = -X$code256)
+  test2 <- big_spLogReg(X2, y01, K = 5)
+  expect_lt(print(cor(summary(test)$beta[[1]], summary(test2)$beta[[1]])), -0.7)
+})
+
+################################################################################
